<script setup>
import { ref, onMounted, computed } from 'vue';
import { Link } from '@inertiajs/vue3';
import { useForm, usePage } from '@inertiajs/vue3';

const page = usePage();
const carMakes = ref([]);
const carModels = ref([]);
const carBodyStyles = ref([]);
const carMakeDisabledClass = ref('w-full mt-1 block disabled:opacity-25 border-gray-300 rounded-md');
const carModelDisabledClass = ref('disabled:opacity-25');
const carBodyStyleDisabledClass = ref('disabled:opacity-25');

const apiUrl = import.meta.env.VITE_API_URL;

const form = useForm({
    year: '',
    make: '',
    model: '',
    bodystyle: '',
});

const years = generateYears(1949, new Date().getFullYear());
const selectedYear = new Date().getFullYear();

function generateYears(start, end) {
  const years = [];
  for (let year = start; year <= end; year++) {
    years.push(year);
  }
  return years;
}

const reversedYears = computed(() => [...years].reverse());

async function fetchCarMakes() {
  try {
    const response = await axios.get(apiUrl+`/carmakers?year=${form.year}`);
    carMakes.value = response.data[0].data;
    form.make = form.model = form.bodystyle = '';
    carModels.value = carBodyStyles.value = [];
  } catch (error) {
    console.error('Error fetching car makes:', error);
  }
}

async function fetchCarModels() {
  try {
    const response = await axios.get(apiUrl+`/carmodels?year=${form.year}&make=${form.make}`);
    carModels.value = response.data[0].data;
    form.model = form.bodystyle = '';
    carBodyStyles.value = [];
  } catch (error) {
    console.error('Error fetching car makes:', error);
  }
}

async function fetchCarBodystyles() {
  try {
    const response = await axios.get(apiUrl+`/carbodystyles?year=${form.year}&make=${form.make}&model=${form.model}`);
    carBodyStyles.value = response.data[0].data;
    form.bodystyle = '';
  } catch (error) {
    console.error('Error fetching car makes:', error);
  }
}

onMounted(async () => {
    if(form.year) {
        carMakeDisabledClass.value = 'w-full mt-1 block border-gray-300 rounded-md';
    }
});
</script>

<template>
    <div class="product_filter">
        <form :action="route('products.all')">
            <div class="col-md-12">
                <InputLabel for="year" value="Year" />

                <select class="w-full mt-1 block border-gray-300 rounded-md" v-model="form.year" id="year" required @change="fetchCarMakes" name="year">
                    <option value="">Select Year</option>
                    <option v-for="year in reversedYears" :key="year" :value="year">{{ year }}</option>
                </select>

                <InputError class="mt-2" :message="form.errors.year" />
            </div>

            <div class="mt-4 col-md-12">
                <InputLabel for="make" value="Make" />

                <select :class="{ 'w-full mt-1 block border-gray-300 rounded-md': true, 'disabled:opacity-25': !form.year }" id="make" v-model="form.make" required @change="fetchCarModels" name="make" :disabled="!form.year">
                    <option value="">Select Make</option>
                    <option v-for="carmake in carMakes" :key="carmake.id" :value="carmake.id">{{ carmake.name }}</option>
                </select>

                <InputError class="mt-2" :message="form.errors.make" />
            </div>

            <div class="mt-4 col-md-12">
                <InputLabel for="model" value="Model" />

                <select :class="{ 'w-full mt-1 block border-gray-300 rounded-md': true, 'disabled:opacity-25': !form.make }" id="model" v-model="form.model" required @change="fetchCarBodystyles" name="model" :disabled="!form.make">
                    <option value="">Select Model</option>
                    <option v-for="carmodel in carModels" :key="carmodel.id" :value="carmodel.id">{{ carmodel.name }}</option>
                </select>

                <InputError class="mt-2" :message="form.errors.model" />
            </div>

            <div class="mt-4 col-md-12">
                <InputLabel for="bodystyle" value="Body Style" />

                <select :class="{ 'w-full mt-1 block border-gray-300 rounded-md': true, 'disabled:opacity-25': !form.model }" id="bodystyle" v-model="form.bodystyle" required name="bodystyle" :disabled="!form.model">
                    <option value="">Select Body Style</option>
                    <option v-for="bodystyle in carBodyStyles" :key="bodystyle.id" :value="bodystyle.id">{{ bodystyle.name }}</option>
                </select>

                <InputError class="mt-2" :message="form.errors.bodystyle" />
            </div>

            <div class="mt-4 col-md-12">
                <input class="product_filter_btn w-full mt-1 block border-gray-300 rounded-md" type="submit" name="product_filter" value="Submit" />
            </div>
        </form>
    </div>
</template>
